Properties Methods Events Direct Link

# Class Ext.calendar.ReminderField

Package: | Ext.calendar
Defined In: | ReminderField.js
Class: | ReminderField
Extends: | Object

A custom combo used for choosing a reminder setting for an event.

This is pretty much a standard combo that is simply pre-configured for the options needed by the calendar components. The default configs are as follows:

    width: 200,
        fieldLabel: 'Reminder',
        mode: 'local',
        triggerAction: 'all',
        forceSelection: true,
        displayField: 'desc',
        valueField: 'value'

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.